@@ -1,26 +1,4 @@
----------------------------------------------------------------------
--- Core types to access the PAGC address standardizer
--- Author: Stephen Woodbridge <woodbri@imaptools.com>
----------------------------------------------------------------------
 
-CREATE TYPE stdaddr AS (
-    building text,
-    house_num text,
-    predir text,
-    qual text,
-    pretype text,
-    name text,
-    suftype text,
-    sufdir text,
-    ruralroute text,
-    extra text,
-    city text,
-    state text,
-    country text,
-    postcode text,
-    box text,
-    unit text
-);
 
 ---------------------------------------------------------------------
 -- Core function to access the PAGC address standardizer
@@ -60,4 +38,3 @@ CREATE OR REPLACE FUNCTION parse_address(IN text,
     AS  '$libdir/address_standardizer-3', 'parse_address'
     LANGUAGE 'c' IMMUTABLE STRICT;
 
-
